==> estateplat-common-1.2.4-20210824.024041-852-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGz.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import javax.persistence.Id;
import java.io.Serializable;

/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version 1.0, 2021/8/23
 * @description 不动产更正表
 */
@Table(name = "bdc_gz")
public class BdcGz implements Serializable {

    @Id
    private String gzid;//更正ID
    private String proid;//项目ID
    private String gzdjlx;//更正登记类型 字典项
    private String gzyj;//更正依据
    private String gzgt;//申请主体
    private String gznr;//更正内容
    private String bdczmh;//不动产登记证明
    private String bdcqzh;//不动产登记证书


    public String getGzid() {
        return gzid;
    }

    public void setGzid(String gzid) {
        this.gzid = gzid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getGzdjlx() {
        return gzdjlx;
    }

    public void setGzdjlx(String gzdjlx) {
        this.gzdjlx = gzdjlx;
    }

    public String getGzyj() {
        return gzyj;
    }

    public void setGzyj(String gzyj) {
        this.gzyj = gzyj;
    }

    public String getGzgt() {
        return gzgt;
    }

    public void setGzgt(String gzgt) {
        this.gzgt = gzgt;
    }

    public String getGznr() {
        return gznr;
    }

    public void setGznr(String gznr) {
        this.gznr = gznr;
    }

    public String getBdczmh() {
        return bdczmh;
    }

    public void setBdczmh(String bdczmh) {
        this.bdczmh = bdczmh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
}

==> estateplat-common-1.2.4-20220818.093634-1085-sources.jar: cn/gtmap/estateplat/model/server/core/BdcGz.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import javax.persistence.Id;
import java.io.Serializable;

/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version 1.0, 2021/8/23
 * @description 不动产更正表
 */
@Table(name = "bdc_gz")
public class BdcGz implements Serializable, InsertVo {

    @Id
    private String gzid;//更正ID
    private String proid;//项目ID
    private String gzdjlx;//更正登记类型 字典项
    private String gzyj;//更正依据
    private String gzgt;//申请主体
    private String gznr;//更正内容
    private String bdczmh;//不动产登记证明
    private String bdcqzh;//不动产登记证书


    public String getGzid() {
        return gzid;
    }

    public void setGzid(String gzid) {
        this.gzid = gzid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getGzdjlx() {
        return gzdjlx;
    }

    public void setGzdjlx(String gzdjlx) {
        this.gzdjlx = gzdjlx;
    }

    public String getGzyj() {
        return gzyj;
    }

    public void setGzyj(String gzyj) {
        this.gzyj = gzyj;
    }

    public String getGzgt() {
        return gzgt;
    }

    public void setGzgt(String gzgt) {
        this.gzgt = gzgt;
    }

    public String getGznr() {
        return gznr;
    }

    public void setGznr(String gznr) {
        this.gznr = gznr;
    }

    public String getBdczmh() {
        return bdczmh;
    }

    public void setBdczmh(String bdczmh) {
        this.bdczmh = bdczmh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
}
